{% extends "base.html" %}
{% load url from future %}
{% block head %}
   <title>Mass Post Office</title>
   <link rel="stylesheet" type="text/css" href="">
{% endblock head%}
{% block content %}

{% endblock content %}

