{% extends "base.html" %}
{% load url from future %}
{% block head %}
   <title>Mass Post Office</title>
   <link rel="stylesheet" type="text/css" href="">
{% endblock head%}
{% block content %}
<div>
    <p>You have successfuly unsubscribed from mass emails on this site. <a href="/">Click here</a> to open <a href="/">Home Page</a>.
</div>
{% endblock content %}

